import Editor from '../../src/modules';
import { Mesh, Object3D } from 'three';

describe('template spec', () => {
  const container = document.createElement('div');
  const canvas = document.createElement('canvas');

  it('MTLLoader에 옵션 meshBasicMaterial을 넣으면 해당 material 변경', async () => {
    const editor = new Editor({ canvas, canvasContainer: container });
    editor.init();

    const mtlPath = '/public/model/mesh.mtl';
    const objPath = '/public/model/mesh.obj';

    editor.loadMTL(mtlPath, objPath, { meshBasicMaterial: true }).then((res) => {
      const objMesh = editor.scene.getObjectByName('MTL_MESH_OBJECT') as THREE.Mesh;

      expect(objMesh).exist;

      // objMesh가 존재하는지 확인
      expect(objMesh).to.exist;

      // objMesh의 재질이 MeshBasicMaterial인지 확인
      if (Array.isArray(objMesh.material)) {
        // 재질이 배열인 경우, 각 재질을 확인
        objMesh.material.forEach((material) => {
          expect(material.type).to.equal('MeshBasicMaterial');
        });
      } else {
        // 단일 재질인 경우, 직접 확인
        expect(objMesh.material.type).to.equal('MeshBasicMaterial');
      }

      // 재질의 존재 여부 확인
      expect(objMesh.material).to.exist;
    });
  });

  it('MTLLoader에 옵션이 없으면 meshPhongMaterial', async () => {
    const editor = new Editor({ canvas, canvasContainer: container });
    await editor.init();

    const mtlPath = '/public/model/mesh.mtl';
    const objPath = '/public/model/mesh.obj';

    await editor.loadMTL(mtlPath, objPath);

    const objMesh = editor.scene.getObjectByName('MTL_MESH_OBJECT') as THREE.Mesh;

    expect(objMesh).exist;

    // objMesh가 존재하는지 확인
    expect(objMesh).to.exist;

    // objMesh의 재질이 MeshBasicMaterial인지 확인
    if (Array.isArray(objMesh.material)) {
      // 재질이 배열인 경우, 각 재질을 확인
      objMesh.material.forEach((material) => {
        expect(material.type).to.equal('MeshPhongMaterial');
      });
    } else {
      // 단일 재질인 경우, 직접 확인
      expect(objMesh.material.type).to.equal('MeshPhongMaterial');
    }

    // 재질의 존재 여부 확인
    expect(objMesh.material).to.exist;
  });
});
